PackedUsize

Struct PackedUsize 

pub struct PackedUsize { /* private fields */ }
A packed usize.

Implementations

Source

impl PackedUsize

pub fn from_bytes(bytes: [u8; 8]) -> Self

Creates a packed usize value from its raw bytes.

pub fn to_le(self) -> usize

Creates an usize from this packed integer, reading its bytes in little endian.

pub fn to_be(self) -> usize

Creates an usize from this packed integer, reading its bytes in big endian.

pub fn to_ne(self) -> usize

Creates an usize from this packed integer, reading its bytes in native endian.