pub struct PackedUsize { /* private fields */ }Expand description
A packed usize.
Implementations
Sourceimpl PackedUsize
impl PackedUsize
Sourcepub fn from_bytes(bytes: [u8; 8]) -> Self
pub fn from_bytes(bytes: [u8; 8]) -> Self
Creates a packed usize value from its raw bytes.
Sourcepub fn to_le(self) -> usize
pub fn to_le(self) -> usize
Creates an usize from this packed integer, reading its bytes in little endian.